@@ -13,7 +13,6 @@ from kubernetes.client.api import CustomObjectsApi
 
 from feast.staging.storage_client import AbstractStagingClient
 from feast_spark.pyspark.abc import (
-    BQ_SPARK_PACKAGE,
     BatchIngestionJob,
     BatchIngestionJobParameters,
     JobLauncher,
@@ -347,7 +346,7 @@ class KubernetesJobLauncher(JobLauncher):
             job_type=OFFLINE_TO_ONLINE_JOB_TYPE,
             main_application_file=jar_s3_path,
             main_class=ingestion_job_params.get_class_name(),
-            packages=[BQ_SPARK_PACKAGE],
+            packages=[],
             jars=[],
             extra_metadata={},
             azure_credentials=self._get_azure_credentials(),
@@ -399,7 +398,7 @@ class KubernetesJobLauncher(JobLauncher):
             job_type=OFFLINE_TO_ONLINE_JOB_TYPE,
             main_application_file=jar_s3_path,
             main_class=ingestion_job_params.get_class_name(),
-            packages=[BQ_SPARK_PACKAGE],
+            packages=[],
             jars=[],
             extra_metadata={},
             azure_credentials=self._get_azure_credentials(),
@@ -460,7 +459,7 @@ class KubernetesJobLauncher(JobLauncher):
             job_type=STREAM_TO_ONLINE_JOB_TYPE,
             main_application_file=jar_s3_path,
             main_class=ingestion_job_params.get_class_name(),
-            packages=[BQ_SPARK_PACKAGE],
+            packages=[],
             jars=extra_jar_paths,
             extra_metadata={METADATA_JOBHASH: job_hash},
             azure_credentials=self._get_azure_credentials(),
